annotate Package
================

:mod:`annotate` Module
----------------------

.. automodule:: numba.annotate.annotate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`annotators` Module
------------------------

.. automodule:: numba.annotate.annotators
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.annotate.tests

